# Weight of Evidence

Package to automatically tree-bin and weight-of-evidence-encode numerical features, to make explainable models that accurately represent feature non-linearities.

## Installing

Todo add

## Examples

Todo add

## Getting setup

1. Install Poetry

2. create a venv with Python=3.10

3. Install poetry packages.

`poetry install`
